/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Application 0.1
import "../../Applications/applications.js" as ApplicationsModel
import "../../Components/"
import "../../Components/ListItems"

AbstractButton {
    id: root
    property var application
    property bool __sideStageEnabled: shell.applicationManager.sideStageEnabled

    height: childrenRect.height
    width: shapedApplicationImage.width

    onClicked: {
        shell.activateApplication(application.desktopFile)
    }

    function updateScreenshotFromCache() {
        applicationImage.updateFromCache();
    }

    // FIXME: should use UbuntuShape from SDK
    UbuntuShapeForItem {
        id: shapedApplicationImage
        anchors {
            top: parent.top
            horizontalCenter: parent.horizontalCenter
        }
        width: (application.stage === ApplicationsModel.MainStage && __sideStageEnabled) ? units.gu(22) : units.gu(11)
        height: (__sideStageEnabled) ? units.gu(22) : units.gu(19)
        radius: "medium"
        image: applicationImage
    }

    ApplicationImage {
        id: applicationImage
        source: application
        width: shapedApplicationImage.width
        height: shapedApplicationImage.height
        fillMode: ApplicationImage.PreserveAspectCrop
    }

    UbuntuShape {
        id: borderPressed

        anchors.fill: shapedApplicationImage
        radius: "medium"
        borderSource: ItemStyle.style.borderPressed
        opacity: root.pressed ? 1.0 : 0.0
        Behavior on opacity { NumberAnimation { duration: 200; easing.type: Easing.OutQuint } }
    }

    // FIXME: label code duplicated with Tile
    Item {
        id: labelContainer
        anchors {
            left: parent.left
            right: parent.right
            top: shapedApplicationImage.bottom
        }
        height: units.gu(2)

        Label {
            id: label
            anchors {
                baseline: parent.bottom
                left: parent.left
                right: parent.right
                leftMargin: units.gu(1)
                rightMargin: units.gu(1)
            }
            text: (application) ? application.name : ""

            color: "#f3f3e7"
            opacity: 0.9
            style: Text.Raised
            styleColor: "black"
            fontSize: "small"
            elide: Text.ElideMiddle
            horizontalAlignment: Text.AlignHCenter
        }
    }
}
