/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import "../../Components"

ResponsiveFlowView {
    id: root

    signal updateScreenshots

    Connections {
        target: shell
        onDashShownChanged: if (shell.dashShown && shell.stageScreenshotsReady) updateScreenshots();
        onStageScreenshotsReadyChanged: if (shell.dashShown && shell.stageScreenshotsReady) updateScreenshots();
    }

    property bool __useFakeScreenshots: !shell.importUbuntuApplicationAvailable

    width: listView.width
    Behavior on height { NumberAnimation { duration: 200; easing.type: Easing.InOutQuad } }

    maximumNumberOfColumns: 10
    minimumHorizontalSpacing: units.gu(2)
    referenceDelegateWidth: units.gu(11)
    verticalSpacing: units.gu(2)

    delegate: Item {
        id: responsiveFlowDelegateContainer
        width: delegateLoader.width + root.horizontalSpacing
        height: delegateLoader.height + root.verticalSpacing

        Loader {
            id: delegateLoader
            anchors {
                top: parent.top
                horizontalCenter: parent.horizontalCenter
            }

            asynchronous: true

            // need to choose delegate depending on if we are using a fake internal running apps model, or using the
            // Ubuntu.Application module for actual data.
            source: if (__useFakeScreenshots) return "RunningApplicationTileFake.qml";
                    else return "RunningApplicationTile.qml"

            onLoaded: {
                if (!__useFakeScreenshots) {
                    item.application = model.application;
                    root.updateScreenshots.connect( item.updateScreenshotFromCache );
                } else {
                    item.application = model;
                }
            }
            //FIXME: add animation on item removal
        }
    }
}

