/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1

Base {
    id: root

    Item {
        anchors {
            left: parent.left
            right: parent.right
            leftMargin: units.gu(2)
            rightMargin: units.gu(4)
        }
        height: units.gu(11.5)

        Row {
            spacing: units.gu(1)

            height: childrenRect.height
            anchors {
                verticalCenter: parent.verticalCenter
                left: parent.left
                right: parent.right
            }

            UbuntuShape {
                id: avatar
                width: units.gu(8)
                height: units.gu(7.5)
                radius: "medium"
                image: Image {
                    source: root.model ? root.model.avatar : ""
                    sourceSize { width: avatar.width; height: avatar.height }
                    fillMode: Image.PreserveAspectCrop
                }
            }

            Image {
                id: icon
                width: units.gu(2)
                height: units.gu(2)
                anchors {
                    top: parent.top
                    topMargin: units.gu(1)
                }
                source: root.model && root.model.model.favorite ? "../graphics/star_favourite.png" : "../graphics/star_not_favourite.png"
            }

            Label {
                width: parent.width - units.gu(10)
                anchors.baseline: icon.bottom
                text: root.model ? root.model.displayName : ""
                color: "#f3f3e7"
                style: Text.Raised
                styleColor: "black"
                opacity: 0.9;
                fontSize: "large"
                wrapMode: Text.WordWrap
                maximumLineCount: 2
                font.weight: Font.Light
            }
        }
    }
}
