/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1

Item {
    id: notification

    property alias iconSource: avatarIcon.source
    property alias summary: summaryLabel.text
    property alias body: bodyLabel.text
    property var actions
    property bool snapDecision: type == "Notifications.Type.SnapDecision"
    property alias secondaryIconSource: secondaryIcon.source

    width: parent.width
    height: childrenRect.height + units.gu (1)
    Behavior on opacity {NumberAnimation{}}

    UbuntuShape {
        id: background

        anchors.fill: parent
        color: "black"
        opacity: 0.85
    }

    UbuntuShape {
        id: icon

        anchors {
            left: parent.left
            leftMargin: units.gu(1)
            top: parent.top
            topMargin: units.gu(1)
        }

        width: units.gu (6)
        height: units.gu (6)
        image: Image {
            id: avatarIcon
            fillMode: Image.PreserveAspectCrop
        }
    }

    Image {
        id: secondaryIcon

        anchors {
            left: icon.right
            leftMargin: units.gu(1)
            top: parent.top
            topMargin: units.gu(1)
        }

        visible: source
        width: units.gu (2)
        height: units.gu (2)
        fillMode: Image.PreserveAspectCrop
    }

    Label {
        id: summaryLabel

        anchors {
            left: secondaryIcon.visible ? secondaryIcon.right : icon.right
            leftMargin: units.gu(1)
            top: icon.top
            right: parent.right
            rightMargin: units.gu(1)
        }

        fontSize: "medium"
        color: "#f3f3e7"
        elide: Text.ElideRight
    }

    Label {
        id: bodyLabel

        anchors {
            left: summaryLabel.left
            top: summaryLabel.bottom
            right: parent.right
            rightMargin: units.gu(1)
        }

        fontSize: "small"
        color: "#f3f3e7"
        opacity: 0.6
        wrapMode: Text.WordWrap
        maximumLineCount: 10
        elide: Text.ElideRight
    }

    Row {
        spacing: units.gu (1)

        parent: notification
        layoutDirection: Qt.RightToLeft

        anchors {
            left: parent.left
            leftMargin: units.gu (1)
            top: (icon.height >= summaryLabel.height + bodyLabel.height) ? icon.bottom : bodyLabel.bottom
            topMargin: snapDecision ? units.gu (1) : 0
            right: parent.right
            rightMargin: units.gu (1)
        }

        Repeater {
            model: actions

            Button {
                id: button

                color: Positioner.isFirstItem ? "#d85317" : "#333333"
                width: (parent.width - units.gu(1)) / 2
                height: units.gu (4)
                text: action_label
                onClicked: print("clicked " + action_id)
            }
        }
    }
}

