/*
 * Copyright (C) 2012 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Gerry Boland <gerry.boland@canonical.com>
 */

#include <QtCore/QProcess>
#include <QtCore/QStringList>
#include <QtCore/QDir>
#include <QDebug>

#include "applicationlauncher.h"

ApplicationLauncher::ApplicationLauncher(QObject* parent)
  : QObject(parent)
  , m_workingDirectory(QString())
{
    setWorkingDirectory(QDir::homePath());
}

QString ApplicationLauncher::workingDirectory() const
{
    return m_workingDirectory;
}

void ApplicationLauncher::setWorkingDirectory(const QString& dir)
{
    if (m_workingDirectory != dir) {
        m_workingDirectory = dir;
        Q_EMIT workingDirectoryChanged();
    }
}

bool ApplicationLauncher::execute(const QString& command)
{
    QStringList args1;
    qint64 pid = 0;
    qDebug() << "executing" << command;
    QProcess process;
    process.setWorkingDirectory(m_workingDirectory);
    return process.startDetached(command);
}
