/*
 * Copyright (C) 2012, 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef HUDCLIENT_H
#define HUDCLIENT_H

#include <QObject>

#include <hud-client.h>

class DeeListModel;

class HudClient : public QObject
{
  Q_OBJECT
  Q_PROPERTY(DeeListModel* results READ results)
  Q_PROPERTY(DeeListModel* applicationsStack READ applicationsStack)
  Q_ENUMS(ToolBarAction)

  public:
    HudClient();
    ~HudClient();

    DeeListModel *results() const;
    DeeListModel *applicationsStack() const;

    enum ToolBarAction
    {
        FullScreenToolBarAction,
        HelpToolBarAction,
        PreferencesToolBarAction,
        QuitToolBarAction,
        UndoToolBarAction
    };

    Q_INVOKABLE void executeCommand(int index);
    Q_INVOKABLE void setSelectedApplication(const QString &selectedApplication);
    Q_INVOKABLE void setQuery(const QString &new_query);
    Q_INVOKABLE void startVoiceQuery();
    Q_INVOKABLE void executeParametrizedAction(const QVariant &values);
    Q_INVOKABLE void updateParametrizedAction(const QVariant &values);
    Q_INVOKABLE void cancelParametrizedAction();
    Q_INVOKABLE void executeToolBarAction(ToolBarAction action);

    void modelReady(bool needDisconnect);
    void modelReallyReady(bool needDisconnect);

  Q_SIGNALS:
    void voiceQueryLoading();
    void voiceQueryListening();
    void voiceQueryHeardSomething();
    void voiceQueryFailed();
    void voiceQueryFinished(const QString &query);
    void commandExecuted();
    void showParametrizedAction(const QString &action, const QVariant &items);

  private:
    HudClientQuery *m_clientQuery;
    DeeListModel *m_results;
    DeeListModel *m_applicationsStack;
    int m_currentActionIndex;
    HudClientParam *m_currentActionParam;
};

#endif
