# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2013 Canonical
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.


# This file contains general purpose test cases for Unity.
# Each test written in this file will be executed for a variety of
# configurations, such as Phone, Tablet or Desktop form factors.
# 
# Sometimes there is the need to disable a certain test for a particular
# configuration. To do so, add this in a new line directly below your test:
# 
#    test_testname.blacklist = (FormFactors.Tablet, FormFactors.Desktop,)
#
# Available form factors are:
# FormFactors.Phone
# FormFactors.Tablet
# FormFactors.Desktop


"""Tests for the Shell"""

from __future__ import absolute_import

from qml_phone_shell.tests import FormFactors
from qml_phone_shell.tests.helpers import TestShellHelpers

from testtools.matchers import Equals, NotEquals, GreaterThan, MismatchError
from autopilot.matchers import Eventually

import unittest
import time
import os
from os import path


class TestShell(TestShellHelpers):
    """Tests the Shell"""

    def test_show_hud(self):
        hud = self.main_window.get_hud()
        self.unlock_greeter()
        self.show_hud()
        self.assertThat(hud.shown, Eventually(Equals(True)))

    def test_show_hud_button_dont_open(self):
        self.unlock_greeter()
        self.open_first_dash_home_app()
        hud_show_button = self.main_window.get_hud_show_button()
        hud = self.main_window.get_hud()
        rect = hud.globalRect
        start_x = int(rect[0] + rect[2] / 2)
        start_y = rect[1] + rect[3] - 1
        self.assertThat(hud_show_button.opacity, Eventually(Equals(0)))
        self.pointing_device.move(start_x, start_y)
        self.pointing_device.press()
        self.pointing_device.move(start_x, start_y - self.grid_size)
        self.assertThat(hud_show_button.opacity, Eventually(Equals(0)))
        self.pointing_device.move(start_x, start_y - self.grid_size * 2)
        self.assertThat(hud_show_button.opacity, Eventually(Equals(1.0)))
        self.assertThat(hud_show_button.mouseOver, Eventually(Equals(False)))
        self.pointing_device.move(start_x, start_y - self.grid_size * 34)
        self.assertThat(hud_show_button.opacity, Eventually(Equals(1.0)))
        self.assertThat(hud_show_button.mouseOver, Eventually(Equals(True)))
        self.pointing_device.move(start_x, start_y - self.grid_size)
        self.assertThat(hud_show_button.opacity, Eventually(Equals(1.0)))
        self.assertThat(hud_show_button.mouseOver, Eventually(Equals(False)))
        self.pointing_device.release()
        self.assertThat(hud_show_button.opacity, Eventually(Equals(0)))
        self.assertThat(hud.shown, Eventually(Equals(False)))

    def test_hide_hud_click(self):
        hud = self.main_window.get_hud()
        self.unlock_greeter()
        self.show_hud()
        self.close_hud_click()
        self.assertThat(hud.shown, Eventually(Equals(False)))

    def test_hide_hud_click_outside_handle(self):
        hud = self.main_window.get_hud()
        self.unlock_greeter()
        self.show_hud()
        rect = hud.globalRect
        x = int(rect[0] + rect[2] / 2)
        y = rect[1] + hud.handleHeight + 1
        self.pointing_device.move(x, y)
        self.pointing_device.click()
        self.assertRaises(MismatchError, lambda: self.assertThat(hud.shown, Eventually(Equals(False), timeout=3)))

    def test_hide_hud_dragging(self):
        hud = self.main_window.get_hud()
        self.unlock_greeter()
        self.show_hud()
        rect = hud.globalRect
        start_x = rect[0] + (rect[2] - rect[0]) / 2
        start_y = rect[1] + 1
        stop_x = start_x
        stop_y = start_y + (rect[3] - rect[1]) / 2
        self.pointing_device.drag(start_x, start_y, stop_x, stop_y)
        self.assertThat(hud.shown, Eventually(Equals(False)))

    def test_hide_hud_launcher(self):
        launcher = self.main_window.get_hud()
        hud = self.main_window.get_hud()
        self.unlock_greeter()
        self.show_hud()
        self.show_launcher()
        self.assertThat(hud.shown, Eventually(Equals(False)))
