/*
 * Copyright (C) 2012, 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <hud-client.h>

#include "libhud_client_stub.h"

/* Schema that is used in the DeeModel representing
   the results */
static const gchar * results_model_schema[] = {
    "v", /* Command ID */
    "s", /* Command Name */
    "a(ii)", /* Highlights in command name */
    "s", /* Description */
    "a(ii)", /* Highlights in description */
    "s", /* Shortcut */
    "u", /* Distance */
    "b", /* Parameterized */
};

/* Schema that is used in the DeeModel representing
   the appstack */
static const gchar * appstack_model_schema[] = {
    "s", /* Application ID */
    "s", /* Icon Name */
    "i", /* Item Type */
};

DeeModel *resultsModel = 0;
DeeModel *appStackModel = 0;

HudClientQuery *hud_client_query_new(const gchar *query)
{
    Q_UNUSED(query);
    return 0;
}

DeeModel *hud_client_query_get_results_model(HudClientQuery *cquery)
{
    Q_UNUSED(cquery);
    if (!resultsModel) {
        resultsModel = dee_sequence_model_new();
        dee_model_set_schema_full(resultsModel, results_model_schema, G_N_ELEMENTS(results_model_schema));

        GVariant * columns[G_N_ELEMENTS(results_model_schema) + 1];
        columns[0] = g_variant_new_variant(g_variant_new_uint64(0));
        columns[1] = g_variant_new_string("Help");
        columns[2] = g_variant_new_array(G_VARIANT_TYPE("(ii)"), NULL, 0);
        columns[3] = g_variant_new_string("Get Help");
        columns[4] = g_variant_new_array(G_VARIANT_TYPE("(ii)"), NULL, 0);
        columns[5] = g_variant_new_string("");
        columns[6] = g_variant_new_uint32(3);
        columns[7] = g_variant_new_boolean(false);
        columns[8] = NULL;
        dee_model_append_row(resultsModel, columns);

        columns[0] = g_variant_new_variant(g_variant_new_uint64(1));
        columns[1] = g_variant_new_string("About");
        columns[3] = g_variant_new_string("Show About");
        dee_model_append_row(resultsModel, columns);

        columns[0] = g_variant_new_variant(g_variant_new_uint64(2));
        columns[1] = g_variant_new_string("Foo");
        columns[3] = g_variant_new_string("Show Foo");
        dee_model_append_row(resultsModel, columns);

        columns[0] = g_variant_new_variant(g_variant_new_uint64(3));
        columns[1] = g_variant_new_string("Bar");
        columns[3] = g_variant_new_string("Show Bar");
        dee_model_append_row(resultsModel, columns);

        columns[0] = g_variant_new_variant(g_variant_new_uint64(4));
        columns[1] = g_variant_new_string("FooBar");
        columns[3] = g_variant_new_string("Show FooBar");
        dee_model_append_row(resultsModel, columns);

        columns[0] = g_variant_new_variant(g_variant_new_uint64(5));
        columns[1] = g_variant_new_string("UltraFooBar");
        columns[3] = g_variant_new_string("Show UltraFooBar");
        dee_model_append_row(resultsModel, columns);
    }
    return resultsModel;
}

DeeModel *hud_client_query_get_appstack_model(HudClientQuery *cquery)
{
    Q_UNUSED(cquery);
    if (!appStackModel) {
        appStackModel = dee_sequence_model_new();
        dee_model_set_schema_full(appStackModel, appstack_model_schema, G_N_ELEMENTS(appstack_model_schema));
        dee_model_append(appStackModel, "app0", "help", 0);
        dee_model_append(appStackModel, "app1", "folder", 1);
    }
    return appStackModel;
}

void hud_client_query_set_appstack_app(HudClientQuery *cquery, const gchar *application_id)
{
    Q_UNUSED(cquery);
    HudClientStub::m_lastSetAppStackApplicationId = application_id;
}

void hud_client_query_execute_toolbar_item(HudClientQuery *cquery, HudClientQueryToolbarItems item, guint timestamp)
{
    Q_UNUSED(cquery);
    Q_UNUSED(timestamp);
    HudClientStub::m_lastExecutedToolbarItem = item;
}

void hud_client_query_set_query(HudClientQuery *cquery, const char *query)
{
    Q_UNUSED(cquery);
    HudClientStub::m_lastSetQuery = QString::fromUtf8(query);
}

void hud_client_query_execute_command(HudClientQuery *cquery, GVariant *command_key, guint timestamp)
{
    Q_UNUSED(cquery);
    Q_UNUSED(timestamp);
    for (uint i = 0; i < dee_model_get_n_rows(resultsModel); ++i) {
        DeeModelIter *iter = dee_model_get_iter_at_row(resultsModel, i);
        GVariant *it_command = dee_model_get_value(resultsModel, iter, 0);
        if (g_variant_equal (command_key, it_command)) {
            HudClientStub::m_lastExecutedCommandRow = i;
            g_variant_unref(it_command);
            return;
        }
        g_variant_unref(it_command);
    }
    HudClientStub::m_lastExecutedCommandRow = -1;
}
