/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../../Greeter"
import Ubuntu.Components 0.1

Item {
    width: units.gu(120)
    height: units.gu(80)
    UnityTestCase {
        name: "GreeterTest"
        when: windowShown
        
        function test_cycle_data() {
            var data = new Array()
            for (var i = 1; i < greeter.model.count; i++) {
                data[i] = {tag: greeter.model.get(i).name, username: "username"+i, uid: i }
            }
            data[greeter.model.count] = {tag: greeter.model.get(0).name, username: "username0", uid: 0 }
            return data
        }
        
        function test_cycle(data) {
            selectionSpy.clear();
            var user = findChild(greeter, data.username)
            mouseClick(user, user.width / 2, user.height / 2)
            var pathview = findChild(greeter, "userList")
            tryCompare(pathview, "currentIndex", data.uid)
            tryCompare(greeter, "locked", greeter.model.get(data.uid).password !== undefined)
            selectionSpy.wait()
            compare(selectionSpy.count, 1)
        }
        
        function test_unlock_password() {
            unlockSpy.clear()
            // First one is Lolas account right now. Replace with password protected user from lightdm
            var account = findChild(greeter, "username1")
            mouseClick(account, 1, 1)
            account = findChild(greeter, "username0")
            mouseClick(account, 1, 1)
            var passwordInput = findChild(greeter, "passwordInput")
            tryCompare(passwordInput, "opacity", 0)
            tryCompare(passwordInput, "opacity", 1)
            mouseClick(passwordInput, 1, 1)
            compare(unlockSpy.count, 0)
            typeString(greeter.model.get(0).password)
            keyClick(Qt.Key_Enter)
            unlockSpy.wait()
        }

        function test_unlock_wrong_password() {
            unlockSpy.clear()
            // First one is Lolas account right now. Replace with password protected user from lightdm
            var account = findChild(greeter, "username1")
            mouseClick(account, 1, 1)
            account = findChild(greeter, "username0")
            mouseClick(account, 1, 1)
            var passwordInput = findChild(greeter, "passwordInput")
            tryCompare(passwordInput, "opacity", 0)
            tryCompare(passwordInput, "opacity", 1)
            mouseClick(passwordInput, 1, 1)
            compare(unlockSpy.count, 0)
            typeString("wr0ng p4ssw0rd")
            keyClick(Qt.Key_Enter)
            compare(unlockSpy.count, 0)
        }

        function test_unlock_no_password() {
            unlockSpy.clear()
            // Last one is the guest account for now. Replace with passwordless user from lightdm
            var guestAccount = findChild(greeter, "username" + (greeter.model.count - 1))
            mouseClick(guestAccount, guestAccount.width / 2, guestAccount.height / 2)
            var passwordInput = findChild(greeter, "passwordInput")
            tryCompare(passwordInput, "opacity", 1)
            mouseClick(passwordInput, 1, 1)
            unlockSpy.wait()
            compare(unlockSpy.count, 1)
        }
    }
    
    Greeter {
        id: greeter
        anchors.fill: parent
    }

    SignalSpy {
        id: unlockSpy
        target: greeter
        signalName: "unlocked"
    }

    SignalSpy {
        id: selectionSpy
        target: greeter
        signalName: "selected"
    }
}
