/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtTest 1.0
import "../../Notifications"

Rectangle {
    id: rootRect
    width: units.gu (40)
    height: units.gu (71)
    color: "white"

    Notifications {
        id: notifications

        anchors.fill: parent
    }

    TestCase {
        id: root
        name: "NotificationRendererTest"
        when: windowShown

        function test_displayNotification_data() {
            return [
             {
                tag: "Snap Decision with secondary icon",
                type: "Notifications.Type.SnapDecision",
                summary: "Tom Ato",
                body: "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.",
                icon: "graphics/avatar1.jpg",
                secondaryIcon: "graphics/icon_phone.png",
                actions: [{ action_id: "ok_id", action_label: "Ok"},
                          { action_id: "cancel_id", action_label: "Cancel"}]
            },
            {
                tag: "Snap Decision without secondary icon",
                type: "Notifications.Type.SnapDecision",
                summary: "Bro Coly",
                body: "At vero eos et accusam et justo duo dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.",
                icon: "graphics/avatar2.jpg",
                secondaryIcon: "",
                actions: [{ action_id: "accept_id", action_label: "Accept"},
                          { action_id: "reject_id", action_label: "Reject"}]
            },
            {
                tag: "Ephemeral notification",
                type: "Notifications.Type.Ephemeral",
                summary: "Cole Raby",
                body: "I did not expect it to be that late.",
                icon: "graphics/avatar3.jpg",
                secondaryIcon: "graphics/facebook.png"
            }
            ]
        }

        function test_displayNotification(data) {
            notifications.displayNotification(data)

            // wait for a second so one can actually see something
            wait(1000)
        }
    }
}
